@@ -1,22 +1,18 @@
 // Libaries
 import _ from 'lodash';
-
 // Constants
 import { DEFAULT_ANNOTATION_COLOR } from '@grafana/ui';
-import { GRID_COLUMN_COUNT, REPEAT_DIR_VERTICAL, GRID_CELL_HEIGHT, GRID_CELL_VMARGIN } from 'app/core/constants';
-
+import { GRID_CELL_HEIGHT, GRID_CELL_VMARGIN, GRID_COLUMN_COUNT, REPEAT_DIR_VERTICAL } from 'app/core/constants';
 // Utils & Services
 import { Emitter } from 'app/core/utils/emitter';
 import { contextSrv } from 'app/core/services/context_srv';
 import sortByKeys from 'app/core/utils/sort_by_keys';
-
 // Types
-import { PanelModel, GridPos } from './PanelModel';
+import { GridPos, panelAdded, PanelModel, panelRemoved } from './PanelModel';
 import { DashboardMigrator } from './DashboardMigrator';
-import { TimeRange, TimeZone } from '@grafana/data';
+import { AppEvent, dateTime, DateTimeInput, isDateTime, PanelEvents, TimeRange, TimeZone, toUtc } from '@grafana/data';
 import { UrlQueryValue } from '@grafana/runtime';
-import { KIOSK_MODE_TV, DashboardMeta } from 'app/types';
-import { toUtc, DateTimeInput, dateTime, isDateTime } from '@grafana/data';
+import { CoreEvents, DashboardMeta, KIOSK_MODE_TV } from 'app/types';
 
 export interface CloneOptions {
   saveVariables?: boolean;
@@ -215,15 +211,15 @@ export class DashboardModel {
 
     panel.setViewMode(fullscreen, this.meta.isEditing);
 
-    this.events.emit('view-mode-changed', panel);
+    this.events.emit(PanelEvents.viewModeChanged, panel);
   }
 
   timeRangeUpdated(timeRange: TimeRange) {
-    this.events.emit('time-range-updated', timeRange);
+    this.events.emit(CoreEvents.timeRangeUpdated, timeRange);
   }
 
   startRefresh() {
-    this.events.emit('refresh');
+    this.events.emit(PanelEvents.refresh);
 
     for (const panel of this.panels) {
       if (!this.otherPanelInFullscreen(panel)) {
@@ -233,7 +229,7 @@ export class DashboardModel {
   }
 
   render() {
-    this.events.emit('render');
+    this.events.emit(PanelEvents.render);
 
     for (const panel of this.panels) {
       panel.render();
@@ -306,7 +302,7 @@ export class DashboardModel {
 
     this.sortPanelsByGridPos();
 
-    this.events.emit('panel-added', panel);
+    this.events.emit(panelAdded, panel);
   }
 
   sortPanelsByGridPos() {
@@ -343,7 +339,7 @@ export class DashboardModel {
     _.pull(this.panels, ...panelsToRemove);
     panelsToRemove.map(p => p.destroy());
     this.sortPanelsByGridPos();
-    this.events.emit('repeats-processed');
+    this.events.emit(CoreEvents.repeatsProcessed);
   }
 
   processRepeats() {
@@ -363,7 +359,7 @@ export class DashboardModel {
     }
 
     this.sortPanelsByGridPos();
-    this.events.emit('repeats-processed');
+    this.events.emit(CoreEvents.repeatsProcessed);
   }
 
   cleanUpRowRepeats(rowPanels: PanelModel[]) {
@@ -596,7 +592,7 @@ export class DashboardModel {
   removePanel(panel: PanelModel) {
     const index = _.indexOf(this.panels, panel);
     this.panels.splice(index, 1);
-    this.events.emit('panel-removed', panel);
+    this.events.emit(panelRemoved, panel);
   }
 
   removeRow(row: PanelModel, removePanels: boolean) {
@@ -659,6 +655,7 @@ export class DashboardModel {
 
       return false;
     })();
+    this.events.emit(CoreEvents.submenuVisibilityChanged, this.meta.submenuEnabled);
   }
 
   getPanelInfoById(panelId: number) {
@@ -761,7 +758,7 @@ export class DashboardModel {
       this.sortPanelsByGridPos();
 
       // emit change event
-      this.events.emit('row-expanded');
+      this.events.emit(CoreEvents.rowExpanded);
       return;
     }
 
@@ -774,7 +771,7 @@ export class DashboardModel {
     row.collapsed = true;
 
     // emit change event
-    this.events.emit('row-collapsed');
+    this.events.emit(CoreEvents.rowCollapsed);
   }
 
   /**
@@ -798,12 +795,12 @@ export class DashboardModel {
     return rowPanels;
   }
 
-  on(eventName: string, callback: (payload?: any) => void) {
-    this.events.on(eventName, callback);
+  on<T>(event: AppEvent<T>, callback: (payload?: T) => void) {
+    this.events.on(event, callback);
   }
 
-  off(eventName: string, callback?: (payload?: any) => void) {
-    this.events.off(eventName, callback);
+  off<T>(event: AppEvent<T>, callback?: (payload?: T) => void) {
+    this.events.off(event, callback);
   }
 
   cycleGraphTooltip() {
@@ -911,7 +908,7 @@ export class DashboardModel {
 
   templateVariableValueUpdated() {
     this.processRepeats();
-    this.events.emit('template-variable-value-updated');
+    this.events.emit(CoreEvents.templateVariableValueUpdated);
   }
 
   expandParentRowFor(panelId: number) {
